robotpy-halsim-gui
==================

Installing this package will allow you to utilize the 2020+ WPILib GUI
simulation from a RobotPy program.

Usage
-----

First, install pyfrc. Then run your robot with the 'sim' argument:

    # Windows
    py -3 ./robot.py sim

    # Linux/OSX
    python3 robot.py sim

WPILib's documentation for using the simulator can be found at http://docs.wpilib.org/en/latest/docs/software/wpilib-tools/robot-simulation/simulation-gui.html
